# pyqt-svg-toolbutton
PyQt SVG icon QToolButton

Parent class of this is `QToolButton` and <a href="https://github.com/yjg30737/pyqt-svg-abstractbutton.git">`SvgAbstractButton`</a>. (Multiple inheritance)

If you want to use svg supporting `QPushButton` instead of `QToolButton`, use <a href="https://github.com/yjg30737/pyqt-svg-button.git">pyqt-svg-button</a>. 

## Requirements
* PyQt5 >= 5.8

## Install
`python -m pip install pyqt-svg-toolbutton`

## Included Packages
* <a href="https://github.com/yjg30737/pyqt-svg-abstractbutton.git">pyqt-svg-abstractbutton</a>
